==> TechRebornJEI-18.2.4-sources.jar: thelm/techrebornjei/recipe/category/AbstractRecipeCategory.java <==
package thelm.techrebornjei.recipe.category;

import java.text.DecimalFormat;
import java.text.NumberFormat;
import java.util.List;

import mezz.jei.api.gui.builder.IRecipeLayoutBuilder;
import mezz.jei.api.gui.builder.IRecipeSlotBuilder;
import mezz.jei.api.gui.drawable.IDrawable;
import mezz.jei.api.helpers.IJeiHelpers;
import mezz.jei.api.helpers.IPlatformFluidHelper;
import mezz.jei.api.recipe.RecipeIngredientRole;
import mezz.jei.api.recipe.RecipeType;
import mezz.jei.api.recipe.category.IRecipeCategory;
import net.fabricmc.fabric.api.transfer.v1.fluid.FluidConstants;
import net.minecraft.class_1799;
import net.minecraft.class_2487;
import net.minecraft.class_2561;
import net.minecraft.class_2588;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_327;
import net.minecraft.class_3611;
import reborncore.client.gui.guibuilder.GuiBuilder;
import reborncore.common.fluid.container.FluidInstance;
import thelm.jeidrawables.gui.render.BlankDrawable;
import thelm.jeidrawables.gui.render.ResourceDrawable;
import thelm.techrebornjei.TechRebornJEI;

public abstract class AbstractRecipeCategory<R> implements IRecipeCategory<R> {

	public static final NumberFormat TIME_FORMAT = new DecimalFormat("###.##");

	public static final ResourceDrawable SLOT = new ResourceDrawable(GuiBuilder.defaultTextureSheet, 150, 0, 18, 18);
	public static final ResourceDrawable TANK_BACKGROUND = new ResourceDrawable(GuiBuilder.defaultTextureSheet, 194, 26, 22, 56);
	public static final ResourceDrawable TANK_FOREGROUND = new ResourceDrawable(GuiBuilder.defaultTextureSheet, 194, 82, 16, 50);

	public final RecipeType<R> recipeType;
	public final class_2561 title;
	public final IDrawable background;

	public AbstractRecipeCategory(RecipeType<R> recipeType, class_2561 title) {
		this.recipeType = recipeType;
		this.title = title;
		background = new BlankDrawable(getWidth(), getHeight());
	}

	public AbstractRecipeCategory(RecipeType<R> recipeType) {
		this.recipeType = recipeType;
		this.title = new class_2588(recipeType.getUid().toString());
		background = new BlankDrawable(getWidth(), getHeight());
	}

	@Override
	public class_2960 getUid() {
		return recipeType.getUid();
	}

	@Override
	public Class<? extends R> getRecipeClass() {
		return recipeType.getRecipeClass();
	}

	@Override
	public RecipeType<R> getRecipeType() {
		return recipeType;
	}

	@Override
	public class_2561 getTitle() {
		return title;
	}

	@Override
	public IDrawable getBackground() {
		return background;
	}

	public int getWidth() {
		return 140;
	}

	public int getHeight() {
		return 56;
	}

	@Override
	public IDrawable getIcon() {
		return null;
	}

	public class_327 font() {
		return class_310.method_1551().field_1772;
	}

	public IJeiHelpers jeiHelpers() {
		return TechRebornJEI.jeiHelpers;
	}

	public IPlatformFluidHelper<?> fluidHelper() {
		return jeiHelpers().getPlatformFluidHelper();
	}

	public IRecipeSlotBuilder addItem(IRecipeLayoutBuilder builder, RecipeIngredientRole ingredientRole, int x, int y, IDrawable background) {
		return builder.addSlot(ingredientRole, x, y).setBackground(background, 8 - background.getWidth() / 2, 8 - background.getHeight() / 2);
	}

	public IRecipeSlotBuilder addItem(IRecipeLayoutBuilder builder, RecipeIngredientRole ingredientRole, int x, int y, List<class_1799> itemStacks, IDrawable background) {
		return addItem(builder, ingredientRole, x, y, background).addItemStacks(itemStacks);
	}

	public IRecipeSlotBuilder addItem(IRecipeLayoutBuilder builder, RecipeIngredientRole ingredientRole, int x, int y, class_1799 itemStack, IDrawable background) {
		return addItem(builder, ingredientRole, x, y, background).addItemStack(itemStack);
	}

	public IRecipeSlotBuilder addFluid(IRecipeLayoutBuilder builder, RecipeIngredientRole ingredientRole, int x, int y, FluidInstance fluidInstance) {
		class_3611 fluid = fluidInstance.getFluid();
		long amount = fluidInstance.getAmount().getRawValue() / (FluidConstants.BUCKET / fluidHelper().bucketVolume());
		class_2487 data = fluidInstance.getTag() == null ? null : fluidInstance.getTag().method_10553();
		return builder.addSlot(ingredientRole, x, y).addFluidStack(fluid, amount, data).setBackground(TANK_BACKGROUND, -3, -3).setOverlay(TANK_FOREGROUND, 0, 0).setFluidRenderer(amount, false, 16, 50);
	}
}

==> TechRebornJEI-18.2.6-sources.jar: thelm/techrebornjei/recipe/category/AbstractRecipeCategory.java <==
package thelm.techrebornjei.recipe.category;

import java.text.DecimalFormat;
import java.text.NumberFormat;
import java.util.List;

import mezz.jei.api.gui.builder.IRecipeLayoutBuilder;
import mezz.jei.api.gui.builder.IRecipeSlotBuilder;
import mezz.jei.api.gui.drawable.IDrawable;
import mezz.jei.api.helpers.IJeiHelpers;
import mezz.jei.api.helpers.IPlatformFluidHelper;
import mezz.jei.api.recipe.RecipeIngredientRole;
import mezz.jei.api.recipe.RecipeType;
import mezz.jei.api.recipe.category.IRecipeCategory;
import net.fabricmc.fabric.api.transfer.v1.fluid.FluidConstants;
import net.minecraft.class_1799;
import net.minecraft.class_2487;
import net.minecraft.class_2561;
import net.minecraft.class_2588;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_327;
import net.minecraft.class_3611;
import reborncore.client.gui.guibuilder.GuiBuilder;
import reborncore.common.fluid.container.FluidInstance;
import thelm.jeidrawables.gui.render.BlankDrawable;
import thelm.jeidrawables.gui.render.ResourceDrawable;
import thelm.techrebornjei.TechRebornJEI;

public abstract class AbstractRecipeCategory<R> implements IRecipeCategory<R> {

	public static final NumberFormat TIME_FORMAT = new DecimalFormat("###.##");

	public static final ResourceDrawable SLOT = new ResourceDrawable(GuiBuilder.defaultTextureSheet, 150, 0, 18, 18);
	public static final ResourceDrawable TANK_BACKGROUND = new ResourceDrawable(GuiBuilder.defaultTextureSheet, 194, 26, 22, 56);
	public static final ResourceDrawable TANK_FOREGROUND = new ResourceDrawable(GuiBuilder.defaultTextureSheet, 194, 82, 16, 50);

	public final RecipeType<R> recipeType;
	public final class_2561 title;
	public final IDrawable background;

	public AbstractRecipeCategory(RecipeType<R> recipeType, class_2561 title) {
		this.recipeType = recipeType;
		this.title = title;
		background = new BlankDrawable(getWidth(), getHeight());
	}

	public AbstractRecipeCategory(RecipeType<R> recipeType) {
		this.recipeType = recipeType;
		this.title = new class_2588(recipeType.getUid().toString());
		background = new BlankDrawable(getWidth(), getHeight());
	}

	@Override
	public class_2960 getUid() {
		return recipeType.getUid();
	}

	@Override
	public Class<? extends R> getRecipeClass() {
		return recipeType.getRecipeClass();
	}

	@Override
	public RecipeType<R> getRecipeType() {
		return recipeType;
	}

	@Override
	public class_2561 getTitle() {
		return title;
	}

	@Override
	public IDrawable getBackground() {
		return background;
	}

	public int getWidth() {
		return 140;
	}

	public int getHeight() {
		return 56;
	}

	@Override
	public IDrawable getIcon() {
		return null;
	}

	public class_327 font() {
		return class_310.method_1551().field_1772;
	}

	public IJeiHelpers jeiHelpers() {
		return TechRebornJEI.jeiHelpers;
	}

	public IPlatformFluidHelper<?> fluidHelper() {
		return jeiHelpers().getPlatformFluidHelper();
	}

	public IRecipeSlotBuilder addItem(IRecipeLayoutBuilder builder, RecipeIngredientRole ingredientRole, int x, int y, IDrawable background) {
		return builder.addSlot(ingredientRole, x, y).setBackground(background, 8 - background.getWidth() / 2, 8 - background.getHeight() / 2);
	}

	public IRecipeSlotBuilder addItem(IRecipeLayoutBuilder builder, RecipeIngredientRole ingredientRole, int x, int y, List<class_1799> itemStacks, IDrawable background) {
		return addItem(builder, ingredientRole, x, y, background).addItemStacks(itemStacks);
	}

	public IRecipeSlotBuilder addItem(IRecipeLayoutBuilder builder, RecipeIngredientRole ingredientRole, int x, int y, class_1799 itemStack, IDrawable background) {
		return addItem(builder, ingredientRole, x, y, background).addItemStack(itemStack);
	}

	public IRecipeSlotBuilder addFluid(IRecipeLayoutBuilder builder, RecipeIngredientRole ingredientRole, int x, int y, FluidInstance fluidInstance) {
		class_3611 fluid = fluidInstance.getFluid();
		long amount = fluidInstance.getAmount().getRawValue() / (FluidConstants.BUCKET / fluidHelper().bucketVolume());
		class_2487 data = fluidInstance.getTag() == null ? null : fluidInstance.getTag().method_10553();
		return builder.addSlot(ingredientRole, x, y).addFluidStack(fluid, amount, data).setBackground(TANK_BACKGROUND, -3, -3).setOverlay(TANK_FOREGROUND, 0, 0).setFluidRenderer(Math.max(amount, 1), false, 16, 50);
	}
}
